{
    "apis": [
        {
            "url": "http://localhost:9999/actors",
            "path": "/actors",
            "description": "Create and manage actors.",
            "api_declaration": {
                "authorizations": [
                    "oauth2"
                ],
                "swaggerVersion": "1.2",
                "apis": [
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "defaultValue": 250,
                                        "description": "The max number of results.",
                                        "format": "int32",
                                        "allowMultiple": false,
                                        "required": false,
                                        "min": 0,
                                        "type": "integer",
                                        "paramType": "query",
                                        "name": "limit"
                                    },
                                    {
                                        "defaultValue": 0,
                                        "description": "The number of records to when returning the results. When paginating results, the page number = ceil(offset/limit)",
                                        "format": "int32",
                                        "allowMultiple": false,
                                        "required": false,
                                        "min": 0,
                                        "type": "integer",
                                        "paramType": "query",
                                        "name": "offset"
                                    }
                                ],
                                "type": "MultipleActorResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "List actors",
                                "nickname": "list",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the actor to add.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "Actor",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "add",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Register an actor.",
                                "type": "SingleActorResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2",
                        "description": "Retrieve a (paginated) list of actors.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "SingleActorResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Retrieve details about a specific actor.",
                                "nickname": "get",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the actor to update.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "Actor",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "type": "SingleActorResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Retrieve details about a specific actor.",
                                "nickname": "update",
                                "method": "PUT"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "EmptyActorResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Delete a specific actor.",
                                "nickname": "delete",
                                "method": "DELETE"
                            }
                        ],
                        "path": "/actors/v2/{actorId}",
                        "description": "Manage a specific actor.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "ActorMessagesResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the current number of messages for an actor.",
                                "nickname": "getMessages",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "ActorMessagesDeleteResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Delete messages from an actor",
                                "nickname": "deleteMessages",
                                "method": "DELETE"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "Optional dictionary of environmental variables",
                                        "allowMultiple": false,
                                        "required": false,
                                        "type": "dict",
                                        "paramType": "query",
                                        "name": "environment"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the message to add.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "MessageRequest",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "sendMessage",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Send a message to an actor mailbox.",
                                "type": "ActorMessageRequestResponse",
                                "method": "POST"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "Optional dictionary of environmental variables",
                                        "allowMultiple": false,
                                        "required": false,
                                        "type": "dict",
                                        "paramType": "query",
                                        "name": "environment"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the message to add.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "MessageRequest",
                                        "paramType": "body",
                                        "name": "message"
                                    }
                                ],
                                "nickname": "sendBinaryMessage",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Send a message to an actor mailbox.",
                                "type": "ActorMessageRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/messages",
                        "description": "Work with actor messages.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "ActorStateResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the current state for an actor.",
                                "nickname": "getState",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The value of the state. Should be JSON-serializable.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "updateState",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Update an actor's state with a JSON-serializable object.",
                                "type": "ActorStateRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/state",
                        "description": "Work with an actor's state.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "ActorPermissionsResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the current permissions for an actor.",
                                "nickname": "getPermissions",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The permission record; user and level fields required.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "PermissionsUpdateRequest",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "updatePermissions",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Update an actor's permissions with a new permission for a user.",
                                "type": "ActorPermissionsRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/permissions",
                        "description": "Work with an actor's permissions.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "MultipleActorWorkerResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "List the current workers for an actor.",
                                "nickname": "listWorkers",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the workers to add.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "AddWorkersRequest",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "addWorker",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Add a worker to an actor.",
                                "type": "ActorWorkersRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/workers",
                        "description": "Work with actor workers.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the worker.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "workerId"
                                    }
                                ],
                                "type": "SingleActorWorkerResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the details about a specific worker for an actor.",
                                "nickname": "getWorker",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the worker.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "workerId"
                                    }
                                ],
                                "nickname": "deleteWorker",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Delete a worker.",
                                "type": "EmptyActorWorkerRequestResponse",
                                "method": "DELETE"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/workers/{workerId}",
                        "description": "Work with a specific worker.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    }
                                ],
                                "type": "MultipleActorNonceResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "List the current nonces for an actor.",
                                "nickname": "listNonces",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": "",
                                        "description": "The description of the nonce to add.",
                                        "allowMultiple": false,
                                        "required": false,
                                        "type": "AddNonceRequest",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "addNonce",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Add a nonce to an actor.",
                                "type": "ActorNonceRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/nonces",
                        "description": "Work with actor nonces.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the nonce.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "nonceId"
                                    }
                                ],
                                "type": "SingleActorNonceResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the details about a specific nonce for an actor.",
                                "nickname": "getNonce",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the nonce.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "nonceId"
                                    }
                                ],
                                "nickname": "deleteNonce",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Delete a nonce.",
                                "type": "EmptyActorNonceRequestResponse",
                                "method": "DELETE"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/nonces/{nonceId}",
                        "description": "Work with a specific nonce.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [],
                                "type": "MultipleActorAliasResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "List all current aliases",
                                "nickname": "listAliases",
                                "method": "GET"
                            },
                            {
                                "parameters": [
									{
                                        "defaultValue": "",
                                        "description": "The description of the alias to add.",
                                        "allowMultiple": false,
                                        "required": false,
                                        "type": "AddAliasRequest",
                                        "paramType": "body",
                                        "name": "body"
                                    }
                                ],
                                "nickname": "addAlias",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Add an alias of an actor.",
                                "type": "ActorAliasRequestResponse",
                                "method": "POST"
                            }
                        ],
                        "path": "/actors/v2/aliases",
                        "description": "Work with aliases.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the alias.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "alias"
                                    }
                                ],
                                "type": "SingleActorAliasResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get the details of a specific alias.",
                                "nickname": "getAlias",
                                "method": "GET"
                            },
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the alias.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "alias"
                                    }
                                ],
                                "nickname": "deleteAlias",
                                "notes": "",
                                "is_websocket": false,
                                "summary": "Delete an alias.",
                                "type": "EmptyActorAliasRequestResponse",
                                "method": "DELETE"
                            }
                        ],
                        "path": "/actors/v2/aliases/{alias}",
                        "description": "Work with a specific alias.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "defaultValue": 250,
                                        "description": "The max number of results.",
                                        "format": "int32",
                                        "allowMultiple": false,
                                        "required": false,
                                        "min": 0,
                                        "type": "integer",
                                        "paramType": "query",
                                        "name": "limit"
                                    },
                                    {
                                        "defaultValue": 0,
                                        "description": "The number of records to when returning the results. When paginating results, the page number = ceil(offset/limit)",
                                        "format": "int32",
                                        "allowMultiple": false,
                                        "required": false,
                                        "min": 0,
                                        "type": "integer",
                                        "paramType": "query",
                                        "name": "offset"
                                    }
                                ],
                                "type": "ExecutionsSummaryResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Summary data of all actor executions.",
                                "nickname": "listExecutions",
                                "method": "GET"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/executions",
                        "description": "Worker with actor executions.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the execution.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "executionId"
                                    }
                                ],
                                "type": "SingleActorExecutionResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Retrieve details about a specific actor execution.",
                                "nickname": "getExecution",
                                "method": "GET"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/executions/{executionId}",
                        "description": "Manage a specific execution for a specific actor.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the execution.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "executionId"
                                    }
                                ],
                                "type": "string",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get result for a specific actor execution.",
                                "nickname": "getOneExecutionResult",
                                "method": "GET"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/executions/{executionId}/results",
                        "description": "Get result for a specific execution.",
                        "has_websocket": false
                    },
                    {
                        "operations": [
                            {
                                "parameters": [
                                    {
                                        "description": "The id of the actor.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "actorId"
                                    },
                                    {
                                        "description": "The id of the execution.",
                                        "allowMultiple": false,
                                        "required": true,
                                        "type": "string",
                                        "paramType": "path",
                                        "name": "executionId"
                                    }
                                ],
                                "type": "ExecutionLogsResponse",
                                "notes": "",
                                "is_websocket": false,
                                "responseMessages": [
                                    {
                                        "message": "Failed to authenticate the user",
                                        "code": 403
                                    },
                                    {
                                        "message": "The service was unable to query the actor database",
                                        "code": 500
                                    }
                                ],
                                "summary": "Get logs for a specific actor execution.",
                                "nickname": "getExecutionLogs",
                                "method": "GET"
                            }
                        ],
                        "path": "/actors/v2/{actorId}/executions/{executionId}/logs",
                        "description": "Manage logs for a specific execution.",
                        "has_websocket": false
                    }
                ],
                "models": {
                    "Actor": {
                        "properties": {
                            "id": {
                                "type": "string",
                                "description": "The unique id of the actor.",
                                "name": "id"
                            },
                            "image": {
                                "type": "string",
                                "description": "Docker image associated with the actor.",
                                "name": "image"
                            },
                            "stateless": {
                                "type": "boolean",
                                "description": "Whether the actor stores private state.",
                                "name": "stateless"
                            },
                            "owner": {
                                "type": "string",
                                "description": "username of the owner of the actor.",
                                "name": "owner"
                            },
                            "description": {
                                "type": "string",
                                "description": "Description of this actor.",
                                "name": "description"
                            },
                            "privileged": {
                                "type": "boolean",
                                "description": "Whether this actor runs in privileged mode.",
                                "name": "privileged"
                            },
                            "defaultEnvironment": {
                                "type": "dict",
                                "description": "Default environmental variables and values.",
                                "name": "defaultEnvironment"
                            },
                            "status": {
                                "type": "string",
                                "description": "Current status of the actor.",
                                "name": "status"
                            }
                        },
                        "id": "Actor",
                        "name": ""
                    },
                    "SingleActorResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "Actor",
                                "name": "result"
                            }
                        },
                        "id": "SingleActorResponse",
                        "name": ""
                    },
                    "EmptyActorResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "String",
                                "name": "result"
                            }
                        },
                        "id": "EmptyActorResponse",
                        "name": ""
                    },
                    "MultipleActorResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "items": {
                                    "$ref": "Actor"
                                },
                                "type": "array",
                                "description": "response body",
                                "name": "result"
                            }
                        },
                        "id": "MultipleActorResponse",
                        "name": ""
                    },
                    "ActorMessages": {
                        "properties": {
                            "messages": {
                                "type": "int",
                                "description": "The number of messages waiting in queue to be processed by this actor.",
                                "name": "messages"
                            }
                        },
                        "id": "ActorMessages",
                        "name": ""
                    },
                    "MessageRequest": {
                        "properties": {
                            "message": {
                                "type": "string",
                                "description": "The message to send to the actor.",
                                "name": "message"
                            }
                        },
                        "id": "MessageRequest",
                        "name": ""
                    },
                    "ActorMessagesResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorMessages",
                                "name": "result"
                            }
                        },
                        "id": "ActorMessagesResponse",
                        "name": ""
                    },
                    "ActorMessageResponse": {
                        "properties": {
                            "executionId": {
                                "type": "string",
                                "description": "The id of the resulting execution.",
                                "name": "executionId"
                            },
                            "msg": {
                                "type": "string",
                                "description": "The message variable for the execution.",
                                "name": "msg"
                            }
                        },
                        "id": "ActorMessageResponse",
                        "name": ""
                    },
                   "ActorMessageRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorMessageResponse",
                                "name": "result"
                            }
                        },
                        "id": "ActorMessageRequestResponse",
                        "name": ""
                   },
                    "ActorState": {
                        "properties": {
                            "state": {
                                "type": "string",
                                "description": "The current state of the actor.",
                                "name": "state"
                            }
                        },
                        "id": "ActorState",
                        "name": ""
                    },
                    "ActorStateResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorState",
                                "name": "result"
                            }
                        },
                        "id": "ActorStateResponse",
                        "name": ""
                    },
                    "ActorStateRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorState",
                                "name": "result"
                            }
                        },
                        "id": "ActorStateRequestResponse",
                        "name": ""
                   },
                    "ActorPermissions": {
                        "properties": {
                            "permissions": {
                                "type": "string",
                                "description": "The dictionary of permissions associated with the actor.",
                                "name": "permissions"
                            }
                        },
                        "id": "ActorPermissions",
                        "name": ""
                    },
                    "ActorPermissionsResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorPermissions",
                                "name": "result"
                            }
                        },
                        "id": "ActorPermissionsResponse",
                        "name": ""
                    },
                   "ActorPermissionsRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorPermissionsResponse",
                                "name": "result"
                            }
                        },
                        "id": "ActorPermissionsRequestResponse",
                        "name": ""
                   },
                    "PermissionsUpdateRequest": {
                        "properties": {
                            "user": {
                                "type": "string",
                                "description": "The user associated with the permission.",
                                "name": "user"
                            },
                            "level": {
                                "type": "string",
                                "description": "The level associated with the permission.",
                                "name": "level"
                            }
                        },
                        "id": "PermissionsUpdateRequest",
                        "name": ""
                   },
                    "ActorWorker": {
                        "properties": {
                            "id": {
                                "type": "string",
                                "description": "The unique id of this worker.",
                                "name": "id"
                            },
                            "image": {
                                "type": "string",
                                "description": "Docker image associated with the actor.",
                                "name": "image"
                            },
                            "last_execution": {
                                "type": "int",
                                "description": "Last execution for this worker.",
                                "name": "last_execution"
                            },
                            "location": {
                                "type": "string",
                                "description": "Location of docker daemon that this worker is using.",
                                "name": "location"
                            },
                            "cid": {
                                "type": "string",
                                "description": "Container id of this worker.",
                                "name": "cid"
                            },
                            "host_id": {
                                "type": "string",
                                "description": "id of the host where this worker is running.",
                                "name": "host_id"
                            },
                            "host_ip": {
                                "type": "string",
                                "description": "IP address of the host where this worker is running.",
                                "name": "host_id"
                            },
                            "status": {
                                "type": "string",
                                "description": "status of the worker.",
                                "name": "status"
                            },
                            "tenant": {
                                "type": "string",
                                "description": "tenant this worker belongs to.",
                                "name": "tenant"
                            }
                        },
                        "id": "ActorWorker",
                        "name": ""
                    },
                    "SingleActorWorkerResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorWorker",
                                "name": "result"
                            }
                        },
                        "id": "SingleActorWorkerResponse",
                        "name": ""
                    },
                    "MultipleActorWorkerResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "items": {
                                    "$ref": "ActorWorker"
                                },
                                "type": "array",
                                "description": "response body",
                                "name": "result"
                            }
                        },
                        "id": "MultipleActorWorkerResponse",
                        "name": ""
                    },
                    "EmptyActorWorkerRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "String",
                                "name": "result"
                            }
                        },
                        "id": "EmptyActorWorkerRequestResponse",
                        "name": ""
                    },
                    "AddWorkersRequest": {
                        "properties": {
                            "num": {
                                "type": "int",
                                "description": "The number of workers to ensure are running.",
                                "name": "num"
                            }
                        },
                        "id": "AddWorkersRequest",
                        "name": ""
                    },
                    "ActorWorkersRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "EmptyActorWorkerRequestResponse",
                                "name": "result"
                            }
                        },
                        "id": "ActorWorkersRequestResponse",
                        "name": ""
                    },
                    "SingleActorAliasResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorAlias",
                                "name": "result"
                            }
                        },
                        "id": "SingleActorAliasResponse",
                        "name": ""
                    },
                    "MultipleActorAliasResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "items": {
                                    "$ref": "ActorAlias"
                                },
                                "type": "array",
                                "description": "response body",
                                "name": "result"
                            }
                        },
                        "id": "MultipleActorAliasResponse",
                        "name": ""
                    },
                    "EmptyActorAliasRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "String",
                                "name": "result"
                            }
                        },
                        "id": "EmptyActorAliasRequestResponse",
                        "name": ""
                    },
                    "AddAliasRequest": {
                        "properties": {
                            "actorId": {
                                "type": "string",
                                "description": "The id of the actor to associate with this alias.",
                                "name": "actorId"
                            },
                            "alias": {
                                "type": "string",
                                "description": "The alias to create.",
                                "name": "alias"
                            }
                        },
                        "id": "AddAliasRequest",
                        "name": ""
                    },
                    "ActorAliasRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorAlias",
                                "name": "result"
                            }
                        },
                        "id": "ActorAliasRequestResponse",
                        "name": ""
                    },
                    "ActorAlias": {
                        "properties": {
                            "alias": {
                                "type": "string",
                                "description": "The alias.",
                                "name": "id"
                            },
                            "actorId": {
                                "type": "string",
                                "description": "Actor id associated with the alias.",
                                "name": "level"
                            }
                        },
                        "id": "ActorAlias",
                        "name": ""
                    },
                    "ActorNonce": {
                        "properties": {
                            "id": {
                                "type": "string",
                                "description": "The unique id of the nonce.",
                                "name": "id"
                            },
                            "level": {
                                "type": "string",
                                "description": "Permission level associated with nonce.",
                                "name": "level"
                            },
                            "actor_id": {
                                "type": "string",
                                "description": "Actor id associated with nonce.",
                                "name": "actor_id"
                            },
                            "last_use_time": {
                                "type": "string",
                                "description": "Last time nonce was used.",
                                "name": "last_use_time"
                            },
                            "max_uses": {
                                "type": "string",
                                "description": "Max number of uses for this nonce.",
                                "name": "max_uses"
                            },
                            "create_time": {
                                "type": "string",
                                "description": "Time stamp when nonce was created.",
                                "name": "create_time"
                            },
                            "remaining_uses": {
                                "type": "int",
                                "description": "Remaining uses of nonce.",
                                "name": "remaining_uses"
                            }
                        },
                        "id": "ActorNonce",
                        "name": ""
                    },

                    "SingleActorNonceResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ActorNonce",
                                "name": "result"
                            }
                        },
                        "id": "SingleActorNonceResponse",
                        "name": ""
                    },
                    "MultipleActorNonceResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "items": {
                                    "$ref": "ActorNonce"
                                },
                                "type": "array",
                                "description": "response body",
                                "name": "result"
                            }
                        },
                        "id": "MultipleActorNonceResponse",
                        "name": ""
                    },
                    "EmptyActorNonceRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "String",
                                "name": "result"
                            }
                        },
                        "id": "EmptyActorNonceRequestResponse",
                        "name": ""
                    },
                    "AddNonceRequest": {
                        "properties": {
                            "maxUses": {
                                "type": "int",
                                "description": "Max number of times nonce can be redeemed.",
                                "name": "num"
                            },
                            "level": {
                                "type": "string",
                                "description": "Permissions level associated with this nonce (default is EXECUTE).",
                                "name": "num"
                            }

                        },
                        "id": "AddNonceRequest",
                        "name": ""
                    },
                    "ActorNonceRequestResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "EmptyActorNonceRequestResponse",
                                "name": "result"
                            }
                        },
                        "id": "ActorNonceRequestResponse",
                        "name": ""
                    },
                    "ExecutionsSummary": {
                        "properties": {
                            "ids": {
                                "items": {
                                    "type": "string"
                                },
                                "type": "array",
                                "description": "The ids of all executions.",
                                "name": "ids"
                            },
                            "actorId": {
                                "type": "string",
                                "description": "The id of the associated actor.",
                                "name": "actorId"
                            },
                            "owner": {
                                "type": "string",
                                "description": "username of the owner of the actor.",
                                "name": "owner"
                            },
                            "totalCpu": {
                                "type": "int",
                                "description": "CPU usage, in user jiffies, of all executions.",
                                "name": "totalCpu"
                            },
                            "totalRuntime": {
                                "type": "int",
                                "description": "Runtime, in milliseconds, of all executions.",
                                "name": "totalRuntime"
                            },
                            "totalIo": {
                                "type": "int",
                                "description": "Block I/O usage, in number of 512-byte sectors read from and written to, by all executions.",
                                "name": "totalIo"
                            }
                        },
                        "id": "ExecutionsSummary",
                        "name": ""
                    },
                    "ExecutionsSummaryResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ExecutionsSummary",
                                "name": "result"
                            }
                        },
                        "id": "ExecutionsSummaryResponse",
                        "name": ""
                    },
                    "Execution": {
                        "properties": {
                            "id": {
                                "type": "string",
                                "description": "The id of this executions.",
                                "name": "id"
                            },
                            "actorId": {
                                "type": "string",
                                "description": "The id of the associated actor.",
                                "name": "actorId"
                            },
                            "owner": {
                                "type": "string",
                                "description": "username of the owner of the actor.",
                                "name": "owner"
                            },
                            "status": {
                                "type": "string",
                                "description": "status of the execution.",
                                "name": "status"
                            },
                            "cpu": {
                                "type": "int",
                                "description": "CPU usage, in user jiffies, of this execution.",
                                "name": "cpu"
                            },
                            "runtime": {
                                "type": "int",
                                "description": "Runtime, in milliseconds, of this execution.",
                                "name": "runtime"
                            },
                            "io": {
                                "type": "int",
                                "description": "Block I/O usage, in number of 512-byte sectors read from and written to, by this execution.",
                                "name": "io"
                            }
                        },
                        "id": "Execution",
                        "name": ""
                    },
                    "SingleActorExecutionResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "Execution",
                                "name": "result"
                            }
                        },
                        "id": "SingleActorExecutionResponse",
                        "name": ""
                    },
                    "MultipleExecutionResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "items": {
                                    "$ref": "Execution"
                                },
                                "type": "array",
                                "description": "response body",
                                "name": "result"
                            }
                        },
                        "id": "MultipleExecutionResponse",
                        "name": ""
                    },
                    "ExecutionLogs": {
                        "properties": {
                            "logs": {
                                "type": "string",
                                "description": "The logs (standard out) of this execution.",
                                "name": "id"
                            }
                        },
                        "id": "ExecutionLogs",
                        "name": ""
                    },
                    "ExecutionLogsResponse": {
                        "properties": {
                            "status": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "status"
                            },
                            "message": {
                                "type": "string",
                                "description": "success or failure",
                                "name": "message"
                            },
                            "result": {
                                "type": "ExecutionLogs",
                                "name": "result"
                            }
                        },
                        "id": "ExecutionLogsResponse",
                        "name": ""
                    }
                },
                "basePath": "https://{{ api_server_base }}",
                "resourcePath": "/actors/v2",
                "apiVersion": "0.5.2"
            },
            "name": "actors"
        }
    ]
}
